---
name: Feature request
about: Let us know if you have a feature request or enhancement
title: '<Title>'
labels: 'Issue: Feature Request'
assignees: ''
---

## Description
<!--A clear and concise description of what you want to achieve. An image or a code example is worth thousand words! -->

## Context
<!--Why is this change important to you? How would you use it? How can it benefit other users?-->

## Possible Implementation
<!--(Optional) Suggest an idea for implementing the addition or change. -->

## Possible Alternatives
<!-- (Optional) Describe any alternative solutions or features you've considered. -->
